package com.rthoni.stssaguenay.ui.fragments;

import android.content.DialogInterface;
import android.os.Bundle;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.support.v7.app.AlertDialog;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;

import com.rthoni.stssaguenay.R;
import com.rthoni.stssaguenay.business.STSBusiness;
import com.rthoni.stssaguenay.dbo.FavouriteStopDbo;

import java.util.List;
import java.util.Vector;

import butterknife.BindView;
import butterknife.ButterKnife;

/**
 * Created by robin on 9/29/16.
 */
public class HomeFragment extends Fragment {

    @BindView(R.id.listFavouritesStops)
    RecyclerView _favouritesStopsList;

    FavouriteStopsAdapter _adapter;

    public static class ViewHolder extends RecyclerView.ViewHolder {
        public View _parentView;
        public TextView _textView;
        public ViewHolder(View v) {
            super(v);
            _parentView = v;
        }
    }

    public class FavouriteStopsAdapter extends RecyclerView.Adapter<ViewHolder> {

        private List<FavouriteStopDbo> _favourites;

        @Override
        public ViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
            View v = LayoutInflater.from(parent.getContext())
                    .inflate(R.layout.favourite_stop_recycler_view_item, parent, false);
            ViewHolder vh = new ViewHolder(v);
            vh._textView = (TextView) v.findViewById(R.id.textView);
            return vh;
        }

        @Override
        public void onBindViewHolder(ViewHolder holder, int position) {
            final FavouriteStopDbo favouriteStopDbo = _favourites.get(position);
            holder._textView.setText(favouriteStopDbo.getStop().getFullName());
            holder._parentView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    onFavouriteClicked(favouriteStopDbo);
                }
            });
            holder._parentView.setOnLongClickListener(new View.OnLongClickListener() {
                @Override
                public boolean onLongClick(View v) {
                    onFavouriteLongClicked(favouriteStopDbo);
                    return true;
                }
            });
        }

        @Override
        public int getItemCount() {
            return _favourites == null ? 0 : _favourites.size();
        }

        public void setFavourites(List<FavouriteStopDbo> favourites) {
            _favourites = favourites;
            notifyDataSetChanged();
        }
    }

    @Nullable
    @Override
    public View onCreateView(LayoutInflater inflater, @Nullable ViewGroup container, @Nullable Bundle savedInstanceState) {
        View v = inflater.inflate(R.layout.fragment_home, container, false);
        ButterKnife.bind(this, v);

        _adapter = new FavouriteStopsAdapter();
        _favouritesStopsList.setAdapter(_adapter);
        _favouritesStopsList.setLayoutManager(new LinearLayoutManager(getContext()));

        loadFavourites();

        return v;
    }

    public void loadFavourites()
    {
        List<FavouriteStopDbo> favourites = STSBusiness.getFavouriteStops(getContext());
        _adapter.setFavourites(favourites);
    }

    public void onFavouriteClicked(FavouriteStopDbo favouriteStopDbo)
    {
    }

    public void onFavouriteLongClicked(final FavouriteStopDbo favouriteStopDbo)
    {
        new AlertDialog.Builder(getContext())
                .setIcon(android.R.drawable.ic_dialog_alert)
                .setTitle(R.string.favourite_remove)
                .setMessage(getString(R.string.favourite_remove_confirm, favouriteStopDbo.getStop().getFullName()))
                .setPositiveButton(android.R.string.yes, new DialogInterface.OnClickListener()
                {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {

                        List<FavouriteStopDbo> favouriteStopDbos = STSBusiness.getFavouriteStops(getContext());
                        for (int i = 0; i < favouriteStopDbos.size(); ++i) {
                            if (favouriteStopDbos.get(i).getStop().getId().equals(favouriteStopDbo.getStop().getId())) {
                                favouriteStopDbos.remove(i--);
                            }
                        }
                        STSBusiness.setFavouriteStops(getContext(), favouriteStopDbos);

                        Toast.makeText(getContext(), getString(R.string.favourite_removed, favouriteStopDbo.getStop().getFullName()), Toast.LENGTH_LONG).show();
                        loadFavourites();
                    }

                })
                .setNegativeButton(android.R.string.no, null)
                .show();
    }
}
